@@ -19,7 +19,7 @@ Readonly::Scalar my $LAST_INDEX => -1;
 Readonly::Scalar my $LINE_SIZE => 79;
 Readonly::Scalar my $SPACE => q{ };
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Finalize Tags output.
 sub finalize {
@@ -417,7 +417,9 @@ sub _put_data {
 	}
 
 	# Process data callback.
-	if (none { $_ eq $self->{'printed_tags'}->[0] } @{$self->{'no_data_callback'}}) {
+	if (none { defined $self->{'printed_tags'}->[0] && $_ eq $self->{'printed_tags'}->[0] }
+		@{$self->{'no_data_callback'}}) {
+
 		$self->_process_callback(\@data, 'data_callback');
 	}
 
@@ -838,6 +840,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
